Pathfinder is written and mainted by John Keyes and 
various contributors:

Development Lead
````````````````

- John Keyes <john@keyes.ie>


Patches and Suggestions
```````````````````````

- Michele Lacchia
